==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ecr/kotlin/outputs/GetAuthorizationTokenResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ecr.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A collection of values returned by getAuthorizationToken.
 * @property authorizationToken Temporary IAM authentication credentials to access the ECR repository encoded in base64 in the form of `user_name:password`.
 * @property expiresAt Time in UTC RFC3339 format when the authorization token expires.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property password Password decoded from the authorization token.
 * @property proxyEndpoint Registry URL to use in the docker login command.
 * @property registryId
 * @property userName User name decoded from the authorization token.
 */
public data class GetAuthorizationTokenResult(
    public val authorizationToken: String,
    public val expiresAt: String,
    public val id: String,
    public val password: String,
    public val proxyEndpoint: String,
    public val registryId: String? = null,
    public val userName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ecr.outputs.GetAuthorizationTokenResult):
            GetAuthorizationTokenResult = GetAuthorizationTokenResult(
            authorizationToken = javaType.authorizationToken(),
            expiresAt = javaType.expiresAt(),
            id = javaType.id(),
            password = javaType.password(),
            proxyEndpoint = javaType.proxyEndpoint(),
            registryId = javaType.registryId().map({ args0 -> args0 }).orElse(null),
            userName = javaType.userName(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ecr/kotlin/outputs/GetAuthorizationTokenResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ecr.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A collection of values returned by getAuthorizationToken.
 * @property authorizationToken Temporary IAM authentication credentials to access the ECR repository encoded in base64 in the form of `user_name:password`.
 * @property expiresAt Time in UTC RFC3339 format when the authorization token expires.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property password Password decoded from the authorization token.
 * @property proxyEndpoint Registry URL to use in the docker login command.
 * @property registryId
 * @property userName User name decoded from the authorization token.
 */
public data class GetAuthorizationTokenResult(
    public val authorizationToken: String,
    public val expiresAt: String,
    public val id: String,
    public val password: String,
    public val proxyEndpoint: String,
    public val registryId: String? = null,
    public val userName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ecr.outputs.GetAuthorizationTokenResult): GetAuthorizationTokenResult = GetAuthorizationTokenResult(
            authorizationToken = javaType.authorizationToken(),
            expiresAt = javaType.expiresAt(),
            id = javaType.id(),
            password = javaType.password(),
            proxyEndpoint = javaType.proxyEndpoint(),
            registryId = javaType.registryId().map({ args0 -> args0 }).orElse(null),
            userName = javaType.userName(),
        )
    }
}
